<?php

/**
 * @package     EU e-Privacy Directive
 * @copyright   Copyright (C) 2009 - 2014 Michael Richey. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
defined('_JEXEC') or die;

class plgAjaxEprivacy extends JPlugin {

	public function onAjaxEprivacy() {
		$this->app = JFactory::getApplication();
		$this->input = $this->app->input;
		$method = $this->input->get('method', 'error');
		if(!method_exists($this,'_'.$method))
		{
			return $this->_error();
		}
		
		$userparams = JComponentHelper::getParams('com_users');
		$sysparams = $this->sysParams();
		$this->_defaultACL = (integer)$userparams->get('guest_usergroup', 1);
		$this->_cookieACL = (integer)$sysparams->get('cookieACL', $this->_defaultACL);		
		return json_encode($this->{'_' . $method}($sysparams)? : $this->error());
	}

	// exposed methods globally available are prefixed with a single underscore
	private function _error() {
		return false;
	}
	
	private function _accept($sysparams) {
		$this->app->setUserState('plg_system_eprivacy', true);	
		$config = JFactory::getConfig();
		$name = 'plg_system_eprivacy';
		$value = date('Y-m-d');
		$expires = time() + 60 * 60 * 24 * (int) $this->params->get('longtermcookieduration', 30);
		$path = strlen($config->get('cookie_path')) ? $config->get('cookie_path') : '/';
		$domain = strlen($config->get('cookie_domain')) ? $config->get('cookie_domain') : filter_input(INPUT_SERVER,'HTTP_HOST');
		$this->input->cookie->set($name, $value, $expires, $path, $domain, false, false);
		if ($sysparams->get('logaccept', false) && $sysparams->get('geoplugin',false))
		{
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);
			$query->insert('#__plg_system_eprivacy_log');
			$query->columns('ip,state,accepted');
			$values = array();
			$values['ip'] = $db->quote(filter_input('SERVER','REMOTE_ADDR'));
			$values['state'] = $db->quote($this->input->get('country','not detected'));
			$values['accepted'] = $db->quote(JFactory::getDate()->toSql());
			$query->values(implode(',', $values));
			$db->setQuery($query);
			$db->execute();
		} else {
			$this->app->setUserState('plg_system_eprivacy_non_eu', false);
		}
		return true;
	}

	private function _decline() {
		$app = JFactory::getApplication();
		$app->setUserState('plg_system_eprivacy', false);
		if (strlen(filter_input(INPUT_SERVER,'HTTP_COOKIE')))
		{
			$config = JFactory::getConfig();
			$cookies = explode(';', filter_input(INPUT_SERVER,'HTTP_COOKIE'));
			foreach ($cookies as $cookie)
			{
				$parts = explode('=', $cookie);
				$name = trim($parts[0]);
				$this->input->cookie->set($name, null, -3600);
				$this->input->cookie->set($name, null, -3600, $config->get('cookie_path','/'), $config->get('cookie_domain',filter_input(INPUT_SERVER,'HTTP_HOST')));
				setcookie($name);
			}
		}	
		return true;
	}

	// really private methods have no underscore
	private function sysParams() {
		$plugin = JPluginHelper::getPlugin('system','eprivacy');
		$params = new JRegistry($plugin->params);
		return $params;
	}
}
